==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Personal" : "Henkilökohtainen",
    "Contacts" : "Yhteystiedot",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tekniset yksityiskohdat",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "Personal" : "Henkilökohtainen",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Contacts" : "Yhteystiedot",
    "Technical details" : "Tekniset yksityiskohdat",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "CalDAV server" : "CalDAV-palvelin",
    "Send invitations to attendees" : "Lähetä kutsut osallistujille",
    "Please make sure to properly set up the email settings above." : "Varmista, että määrität sähköpostiasetukset oikein yläpuolelle. "
},
"nplurals=2; plural=(n != 1);");
